@@ -374,11 +374,13 @@ dvi_document_file_exporter_end (EvFileExporter *exporter)
 	gboolean success;
 	
 	DviDocument *dvi_document = DVI_DOCUMENT(exporter);
+	gchar* quoted_filename = g_shell_quote (dvi_document->context->filename);
 	
-	command_line = g_strdup_printf ("dvipdfm %s -o %s \"%s\"", /* dvipdfm -s 1,2,.., -o exporter_filename dvi_filename */
+	command_line = g_strdup_printf ("dvipdfm %s -o %s %s", /* dvipdfm -s 1,2,.., -o exporter_filename dvi_filename */
 					dvi_document->exporter_opts->str,
 					dvi_document->exporter_filename,
-					dvi_document->context->filename);
+					quoted_filename);
+	g_free (quoted_filename);
 	
 	success = g_spawn_command_line_sync (command_line,
 					     NULL,
@@ -422,17 +424,17 @@ dvi_document_file_exporter_iface_init (EvFileExporterInterface *iface)
 static gboolean
 hsb2rgb (float h, float s, float v, guchar *red, guchar *green, guchar *blue)
 {
-        float i, f, p, q, t, r, g, b;
-
-        if (h == 360)
-                h = 0;
-        else if ((h > 360) || (h < 0))
-                return FALSE;
+        float f, p, q, t, r, g, b;
+        int i;
 
         s /= 100;
         v /= 100;
         h /= 60;
         i = floor (h);
+        if (i == 6)
+                i = 0;
+        else if ((i > 6) || (i < 0))
+                return FALSE;
         f = h - i;
         p = v * (1 - s);
         q = v * (1 - (s * f));
