@@ -675,10 +675,9 @@ static void
 egg_toolbars_model_class_init (EggToolbarsModelClass *klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
-  volatile GType flags_type; /* work around gcc's optimiser */
 
   /* make sure the flags type is known */
-  flags_type = EGG_TYPE_TB_MODEL_FLAGS;
+  g_type_ensure (EGG_TYPE_TB_MODEL_FLAGS);
 
   object_class->finalize = egg_toolbars_model_finalize;
 
@@ -946,12 +945,24 @@ egg_toolbars_model_toolbar_nth (EggToolbarsModel *model,
   return tdata->name;
 }
 
+/**
+ * egg_toolbars_model_get_types:
+ * @model:
+ *
+ * Returns: (transfer none) (element-type EggToolbarsItemType):
+ */
 GList *
 egg_toolbars_model_get_types (EggToolbarsModel *model)
 {
   return model->priv->types;
 }
 
+/**
+ * egg_toolbars_model_set_types:
+ * @model:
+ * @types: (element-type EggToolbarsItemType):
+ *
+ */
 void
 egg_toolbars_model_set_types (EggToolbarsModel *model, GList *types)
 {
@@ -966,6 +977,12 @@ fill_avail_array (gpointer key, gpointer value, GPtrArray *array)
       g_ptr_array_add (array, key);
 }
 
+/**
+ * egg_toolbars_model_get_name_avail:
+ * @model:
+ *
+ * Returns: (element-type utf8) (transfer container):
+ */
 GPtrArray *
 egg_toolbars_model_get_name_avail (EggToolbarsModel *model)
 {
