@@ -73,6 +73,12 @@ typedef struct {
 	EvImage *image;
 } ImageDNDInfo;
 
+typedef enum {
+	EV_PAN_ACTION_NONE,
+	EV_PAN_ACTION_NEXT,
+	EV_PAN_ACTION_PREV
+} EvPanAction;
+
 /* Annotation popup windows */
 typedef struct {
 	GtkWidget *window;
@@ -144,6 +150,8 @@ struct _EvView {
 	gint scroll_x;
 	gint scroll_y;	
 
+	/* Delta sum for emulating normal scrolling */
+	gdouble       total_delta;
 	PendingScroll pending_scroll;
 	gboolean      pending_resize;
 	EvPoint       pending_point;
@@ -193,15 +201,28 @@ struct _EvView {
 	/* Annotations */
 	GList             *window_children;
 	EvViewWindowChild *window_child_focus;
-	EvMapping         *focus_annotation;
 	gboolean           adding_annot;
 	EvAnnotationType   adding_annot_type;
 
+	/* Focus */
+	EvMapping *focused_element;
+	guint focused_element_page;
+
 	/* Synctex */
 	EvMapping *synctex_result;
 
 	/* Accessibility */
 	AtkObject *accessible;
+
+	/* Gestures */
+	GtkGesture *pan_gesture;
+	GtkGesture *zoom_gesture;
+	gdouble prev_zoom_gesture_scale;
+	EvPanAction pan_action;
+
+	/* Current zoom center */
+	gdouble zoom_center_x;
+	gdouble zoom_center_y;
 };
 
 struct _EvViewClass {
@@ -221,6 +242,8 @@ struct _EvViewClass {
 					   EvSourceLink   *link);
 	void    (*annot_added)            (EvView         *view,
 					   EvAnnotation   *annot);
+	void    (*annot_removed)          (EvView         *view,
+					   EvAnnotation   *annot);
 	void    (*layers_changed)         (EvView         *view);
 };
 
@@ -248,5 +271,9 @@ void _ev_view_transform_doc_rect_to_view_rect (EvView       *view,
 					       EvRectangle  *doc_rect,
 					       GdkRectangle *view_rect);
 
+void _ev_view_set_focused_element (EvView *view,
+                                   EvMapping *element_mapping,
+                                   gint page);
+
 #endif  /* __EV_VIEW_PRIVATE_H__ */
 
