@@ -29,10 +29,6 @@
 
 #include "ev-previewer-window.h"
 
-#if GTK_CHECK_VERSION (3, 0, 0)
-#define gtk_vbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_VERTICAL,Y)
-#endif
-
 struct _EvPreviewerWindow {
 	GtkWindow         base_instance;
 
@@ -74,10 +70,22 @@ G_DEFINE_TYPE (EvPreviewerWindow, ev_previewer_window, GTK_TYPE_WINDOW)
 static gdouble
 get_screen_dpi (EvPreviewerWindow *window)
 {
-	GdkScreen *screen;
+	GdkScreen  *screen;
+#if GTK_CHECK_VERSION (3, 22, 0)
+	GdkMonitor *monitor;
+	GdkDisplay *display;
+#else
+	gint        monitor;
+#endif
 
 	screen = gtk_window_get_screen (GTK_WINDOW (window));
-	return ev_document_misc_get_screen_dpi (screen);
+#if GTK_CHECK_VERSION (3, 22, 0)
+	display = gdk_screen_get_display (screen);
+	monitor = gdk_display_get_primary_monitor (display);
+#else
+	monitor = gdk_screen_get_primary_monitor (screen);
+#endif
+	return ev_document_misc_get_screen_dpi (screen, monitor);
 }
 
 #if GTKUNIXPRINT_ENABLED
@@ -590,7 +598,7 @@ ev_previewer_window_constructor (GType                  type,
 
 	view_sizing_mode_changed (window->model, NULL, window);
 
-	vbox = gtk_vbox_new (FALSE, 0);
+	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 
 	toolbar = gtk_ui_manager_get_widget (window->ui_manager, "/PreviewToolbar");
 	gtk_box_pack_start (GTK_BOX (vbox), toolbar, FALSE, FALSE, 0);
