@@ -25,11 +25,6 @@
 
 #include "ev-message-area.h"
 
-#if GTK_CHECK_VERSION (3, 0, 0)
-#define gtk_hbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_HORIZONTAL,Y)
-#define gtk_vbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_VERTICAL,Y)
-#endif
-
 #define EV_MESSAGE_AREA_GET_PRIVATE(obj) \
 	(G_TYPE_INSTANCE_GET_PRIVATE ((obj), EV_TYPE_MESSAGE_AREA, EvMessageAreaPrivate))
 
@@ -101,16 +96,20 @@ ev_message_area_init (EvMessageArea *area)
 
 	area->priv = EV_MESSAGE_AREA_GET_PRIVATE (area);
 
-	area->priv->main_box = gtk_vbox_new (FALSE, 12);
+	area->priv->main_box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 12);
 
-	hbox = gtk_hbox_new (FALSE, 12);
-	vbox = gtk_vbox_new (FALSE, 12);
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
+	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 12);
 
 	area->priv->label = gtk_label_new (NULL);
 	gtk_label_set_use_markup (GTK_LABEL (area->priv->label), TRUE);
 	gtk_label_set_line_wrap (GTK_LABEL (area->priv->label), TRUE);
 	gtk_label_set_selectable (GTK_LABEL (area->priv->label), TRUE);
+#if GTK_CHECK_VERSION (3, 16, 0)
+	gtk_label_set_xalign (GTK_LABEL (area->priv->label), 0.0);
+#else
 	gtk_misc_set_alignment (GTK_MISC (area->priv->label), 0.0, 0.5);
+#endif
 	gtk_widget_set_can_focus (area->priv->label, TRUE);
 	gtk_box_pack_start (GTK_BOX (vbox), area->priv->label, TRUE, TRUE, 0);
 	gtk_widget_show (area->priv->label);
@@ -119,12 +118,17 @@ ev_message_area_init (EvMessageArea *area)
 	gtk_label_set_use_markup (GTK_LABEL (area->priv->secondary_label), TRUE);
 	gtk_label_set_line_wrap (GTK_LABEL (area->priv->secondary_label), TRUE);
 	gtk_label_set_selectable (GTK_LABEL (area->priv->secondary_label), TRUE);
+#if GTK_CHECK_VERSION (3, 16, 0)
+	gtk_label_set_xalign (GTK_LABEL (area->priv->secondary_label), 0.0);
+#else
 	gtk_misc_set_alignment (GTK_MISC (area->priv->secondary_label), 0.0, 0.5);
+#endif
 	gtk_widget_set_can_focus (area->priv->secondary_label, TRUE);
 	gtk_box_pack_start (GTK_BOX (vbox), area->priv->secondary_label, TRUE, TRUE, 0);
 
-	area->priv->image = gtk_image_new_from_stock (NULL, GTK_ICON_SIZE_DIALOG);
-	gtk_misc_set_alignment (GTK_MISC (area->priv->image), 0.5, 0.0);
+	area->priv->image = gtk_image_new_from_icon_name (NULL, GTK_ICON_SIZE_DIALOG);
+	gtk_widget_set_halign (area->priv->image, GTK_ALIGN_CENTER);
+	gtk_widget_set_valign (area->priv->image, GTK_ALIGN_START);
 	gtk_box_pack_start (GTK_BOX (hbox), area->priv->image, FALSE, FALSE, 0);
 	gtk_widget_show (area->priv->image);
 
@@ -143,21 +147,21 @@ static void
 ev_message_area_set_image_for_type (EvMessageArea *area,
 				    GtkMessageType type)
 {
-	const gchar *stock_id = NULL;
+	const gchar *icon_name = NULL;
 	AtkObject   *atk_obj;
 
 	switch (type) {
 	case GTK_MESSAGE_INFO:
-		stock_id = GTK_STOCK_DIALOG_INFO;
+		icon_name = "dialog-information";
 		break;
 	case GTK_MESSAGE_QUESTION:
-		stock_id = GTK_STOCK_DIALOG_QUESTION;
+		icon_name = "dialog-question";
 		break;
 	case GTK_MESSAGE_WARNING:
-		stock_id = GTK_STOCK_DIALOG_WARNING;
+		icon_name = "dialog-warning";
 		break;
 	case GTK_MESSAGE_ERROR:
-		stock_id = GTK_STOCK_DIALOG_ERROR;
+		icon_name = "dialog-error";
 		break;
 	case GTK_MESSAGE_OTHER:
 		break;
@@ -166,17 +170,17 @@ ev_message_area_set_image_for_type (EvMessageArea *area,
 		break;
 	}
 
-	if (stock_id)
-		gtk_image_set_from_stock (GTK_IMAGE (area->priv->image), stock_id,
+	if (icon_name)
+		gtk_image_set_from_icon_name (GTK_IMAGE (area->priv->image), icon_name,
 					  GTK_ICON_SIZE_DIALOG);
 
 	atk_obj = gtk_widget_get_accessible (GTK_WIDGET (area));
 	if (GTK_IS_ACCESSIBLE (atk_obj)) {
 		atk_object_set_role (atk_obj, ATK_ROLE_ALERT);
-		if (stock_id) {
+		if (icon_name) {
 			GtkStockItem item;
 
-			gtk_stock_lookup (stock_id, &item);
+			gtk_stock_lookup (icon_name, &item);
 			atk_object_set_name (atk_obj, item.label);
 		}
 	}
@@ -308,13 +312,13 @@ ev_message_area_set_image (EvMessageArea *area,
 
 void
 ev_message_area_set_image_from_stock (EvMessageArea *area,
-				      const gchar   *stock_id)
+				      const gchar   *icon_name)
 {
 	g_return_if_fail (EV_IS_MESSAGE_AREA (area));
-	g_return_if_fail (stock_id != NULL);
+	g_return_if_fail (icon_name != NULL);
 	
-	gtk_image_set_from_stock (GTK_IMAGE (area->priv->image),
-				  stock_id,
+	gtk_image_set_from_icon_name (GTK_IMAGE (area->priv->image),
+				  icon_name,
 				  GTK_ICON_SIZE_DIALOG);
 }
 
