@@ -104,7 +104,6 @@ ev_password_view_clicked_cb (GtkWidget      *button,
 static void
 ev_password_view_init (EvPasswordView *password_view)
 {
-	GtkWidget *align;
 	GtkWidget *vbox;
 	GtkWidget *hbox;
 	GtkWidget *image;
@@ -117,11 +116,12 @@ ev_password_view_init (EvPasswordView *password_view)
 	password_view->priv->password_save = G_PASSWORD_SAVE_NEVER;
 
 	/* set ourselves up */
-	align = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
 	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 24);
+	gtk_widget_set_valign (vbox, GTK_ALIGN_CENTER);
+	gtk_widget_set_hexpand (vbox, FALSE);
+	gtk_widget_set_vexpand (vbox, FALSE);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox), 24);
-	gtk_container_add (GTK_CONTAINER (password_view), align);
-	gtk_container_add (GTK_CONTAINER (align), vbox);
+	gtk_container_add (GTK_CONTAINER (password_view), vbox);
 
 	password_view->priv->label =
 		(GtkWidget *) g_object_new (GTK_TYPE_LABEL,
@@ -130,8 +130,8 @@ ev_password_view_init (EvPasswordView *password_view)
 					    NULL);
 	gtk_box_pack_start (GTK_BOX (vbox), password_view->priv->label, FALSE, FALSE, 0);
 
-	image = gtk_image_new_from_stock (GTK_STOCK_DIALOG_AUTHENTICATION,
-					  GTK_ICON_SIZE_DIALOG);
+	image = gtk_image_new_from_icon_name ("dialog-password",
+	                                      GTK_ICON_SIZE_DIALOG);
 	gtk_box_pack_start (GTK_BOX (vbox), image, FALSE, FALSE, 0);
 
 	label = gtk_label_new (NULL);
@@ -150,7 +150,7 @@ ev_password_view_init (EvPasswordView *password_view)
 	g_signal_connect (button, "clicked", G_CALLBACK (ev_password_view_clicked_cb), password_view);
 	gtk_box_pack_end (GTK_BOX (hbox), button, FALSE, FALSE, 0);
 
-	gtk_widget_show_all (align);
+	gtk_widget_show_all (vbox);
 }
 
 /* Public functions */
@@ -237,7 +237,6 @@ ev_password_view_ask_password (EvPasswordView *password_view)
 {
 	GtkDialog *dialog;
 	GtkWidget *content_area, *action_area;
-	GtkWidget *entry_container;
 	GtkWidget *hbox, *main_vbox, *vbox, *icon;
 	GtkWidget *grid;
 	GtkWidget *label;
@@ -257,7 +256,7 @@ ev_password_view_ask_password (EvPasswordView *password_view)
 
 	gtk_window_set_title (GTK_WINDOW (dialog), _("Enter password"));
 	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
-	gtk_window_set_icon_name (GTK_WINDOW (dialog), GTK_STOCK_DIALOG_AUTHENTICATION);
+	gtk_window_set_icon_name (GTK_WINDOW (dialog), "dialog-password");
 	gtk_window_set_transient_for (GTK_WINDOW (dialog), password_view->priv->parent_window);
 	gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
 
@@ -275,8 +274,8 @@ ev_password_view_ask_password (EvPasswordView *password_view)
 	gtk_box_pack_start (GTK_BOX (content_area), hbox, TRUE, TRUE, 0);
 	gtk_widget_show (hbox);
 
-	icon = gtk_image_new_from_stock (GTK_STOCK_DIALOG_AUTHENTICATION,
-					 GTK_ICON_SIZE_DIALOG);
+	icon = gtk_image_new_from_icon_name ("dialog-password",
+	                                      GTK_ICON_SIZE_DIALOG);
 
 	gtk_widget_set_halign (icon, GTK_ALIGN_CENTER);
 	gtk_widget_set_valign (icon, GTK_ALIGN_START);
@@ -312,21 +311,21 @@ ev_password_view_ask_password (EvPasswordView *password_view)
 	gtk_box_pack_start (GTK_BOX (main_vbox), vbox, FALSE, FALSE, 0);
 	gtk_widget_show (vbox);
 
-	/* The table that holds the entries */
-	entry_container = gtk_alignment_new (0.0, 0.0, 1.0, 1.0);
-
-	gtk_alignment_set_padding (GTK_ALIGNMENT (entry_container),
-				   0, 0, 0, 0);
-	
-	gtk_box_pack_start (GTK_BOX (vbox), entry_container,
-			    FALSE, FALSE, 0);
-	gtk_widget_show (entry_container);
-
+	/* The grid that holds the entries */
 	grid = gtk_grid_new ();
 	gtk_grid_set_column_spacing (GTK_GRID (grid), 12);
 	gtk_grid_set_row_spacing (GTK_GRID (grid), 6);
-	gtk_container_add (GTK_CONTAINER (entry_container), grid);
+	gtk_widget_set_valign (grid, GTK_ALIGN_START);
+	gtk_widget_set_hexpand (grid, TRUE);
+	gtk_widget_set_vexpand (grid, TRUE);
+	gtk_widget_set_margin_top (grid, 0);
+	gtk_widget_set_margin_bottom (grid, 0);
+	gtk_widget_set_margin_start (grid, 0);
+	gtk_widget_set_margin_end (grid, 0);
 	gtk_widget_show (grid);
+	gtk_box_pack_start (GTK_BOX (vbox),
+	                    grid,
+	                    FALSE, FALSE, 0);
 
 	label = gtk_label_new_with_mnemonic (_("_Password:"));
 #if GTK_CHECK_VERSION (3, 16, 0)
